Struct pyinrs::Dict

source ·
pub struct Dict<K, V> { /* private fields */ }

Implementations

source

impl<K: Ord, V> Dict<K, V>

source

pub fn new() -> Self

Makes a new, empty Dict.

source

pub fn len(&self) -> usize

Returns the number of elements in the dict.

source

pub fn is_empty(&self) -> bool

Returns true if the dict contains no elements.

source

pub fn iter(&self) -> Iter<'_, K, V>

Gets an iterator over the entries of the dict, sorted by key.

source

pub fn contains(&self, key: &K) -> bool

Returns true if the dict contains a value for the specified key.

source

pub fn get<'a>(&'a self, key: &K, default: &'a V) -> &V

Return a reference of the value for key if key is in the dick, else default value.

source

pub fn keys(&self) -> Set<K>
where K: Clone,

Return a new set of the dict’s keys.

source

pub fn values(&self) -> Set<V>
where V: Ord + Clone,

Return a new set of the dict’s values.

source

pub fn items(&self) -> Set<(K, V)>
where K: Clone, V: Ord + Clone,

Return a new set of the dict’s items.

source

pub fn add(&mut self, key: K, value: V) -> bool

Adds a value to the dict. Returns whether the value was newly inserted.

source

pub fn remove(&mut self, key: &K) -> Option<V>

Removes a key from the dict, returning the value at the key if the key was previously in the dict.

source

pub fn pop(&mut self) -> Option<(K, V)>

Removes the first element from the dict and returns it, if any.

source

pub fn clear(&mut self)

Clears the dict, removing all elements.