pub struct Dict<K, V> { /* private fields */ }Implementations
sourceimpl<K: Ord, V> Dict<K, V>
impl<K: Ord, V> Dict<K, V>
sourcepub fn iter(&self) -> Iter<'_, K, V>
pub fn iter(&self) -> Iter<'_, K, V>
Gets an iterator over the entries of the dict, sorted by key.
sourcepub fn contains(&self, key: &K) -> bool
pub fn contains(&self, key: &K) -> bool
Returns true if the dict contains a value for the specified key.
sourcepub fn get<'a>(&'a self, key: &K, default: &'a V) -> &V
pub fn get<'a>(&'a self, key: &K, default: &'a V) -> &V
Return a reference of the value for key if key is in the dick, else default value.
sourcepub fn add(&mut self, key: K, value: V) -> bool
pub fn add(&mut self, key: K, value: V) -> bool
Adds a value to the dict. Returns whether the value was newly inserted.
sourcepub fn remove(&mut self, key: &K) -> Option<V>
pub fn remove(&mut self, key: &K) -> Option<V>
Removes a key from the dict, returning the value at the key if the key was previously in the dict.